@@ -1,5 +1,5 @@
 package Apache2::AuthCookie::Base;
-$Apache2::AuthCookie::Base::VERSION = '3.28';
+$Apache2::AuthCookie::Base::VERSION = '3.29';
 # ABSTRACT: Common Methods Shared by Apache2 and Apache2_4 AuthCookie Subclasses.
 
 use strict;
@@ -268,10 +268,30 @@ sub login {
         $self->_convert_to_get($r);
     }
 
-    unless (defined $params->param('destination')) {
-        $r->server->log_error("No key 'destination' found in form data");
-        $r->subprocess_env('AuthCookieReason', 'no_cookie');
-        return $auth_type->login_form($r);
+    my $default_destination = $r->dir_config("${auth_name}DefaultDestination");
+    my $destination         = $params->param('destination');
+
+    if (is_blank($destination)) {
+        if (!is_blank($default_destination)) {
+            $destination = $default_destination;
+            $r->server->log_error("destination set to $destination");
+        }
+        else {
+            $r->server->log_error("No key 'destination' found in form data");
+            $r->subprocess_env('AuthCookieReason', 'no_cookie');
+            return $auth_type->login_form($r);
+        }
+    }
+
+    if ($r->dir_config("${auth_name}EnforceLocalDestination")) {
+        if ($destination !~ m|^\s*/|) {
+            $r->server->log_error("invalid destination $destination detected for uri ",$r->uri);
+
+            unless (is_blank($default_destination)) {
+                $destination = $default_destination;
+                $r->server->log_error("destination changed to $destination");
+            }
+        }
     }
 
     # Get the credentials from the data posted by the client
@@ -291,7 +311,7 @@ sub login {
     unless ($ses_key) {
         $r->server->log_error("Bad credentials") if $debug >= 2;
         $r->subprocess_env('AuthCookieReason', 'bad_credentials');
-        $r->uri($self->untaint_destination($params->param('destination')));
+        $r->uri($self->untaint_destination($destination));
         return $auth_type->login_form($r);
     }
 
@@ -305,11 +325,11 @@ sub login {
     $self->handle_cache($r);
 
     if ($debug >= 2) {
-        $r->server->log_error("redirect to ", $params->param('destination'));
+        $r->server->log_error("redirect to $destination");
     }
 
     $r->headers_out->set(
-        "Location" => $self->untaint_destination($params->param('destination')));
+        "Location" => $self->untaint_destination($destination));
 
     return HTTP_MOVED_TEMPORARILY;
 }
@@ -541,7 +561,7 @@ Apache2::AuthCookie::Base - Common Methods Shared by Apache2 and Apache2_4 AuthC
 
 =head1 VERSION
 
-version 3.28
+version 3.29
 
 =head1 DESCRIPTION
 
