@@ -1,5 +1,5 @@
 package Apache2_4::AuthCookie;
-$Apache2_4::AuthCookie::VERSION = '3.27';
+$Apache2_4::AuthCookie::VERSION = '3.29';
 # ABSTRACT: Perl Authentication and Authorization via cookies for Apache 2.4
 
 use strict;
@@ -52,13 +52,15 @@ sub authz_handler  {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Apache2_4::AuthCookie - Perl Authentication and Authorization via cookies for Apache 2.4
 
 =head1 VERSION
 
-version 3.27
+version 3.29
 
 =head1 SYNOPSIS
 
@@ -84,10 +86,14 @@ MethodHandlers, Authen, and Authz compiled in.
  PerlSetVar WhatEverSessionTimeout +30m
 
  # to enable the HttpOnly cookie property, use HttpOnly.
- # this is an MS extension.  See:
+ # This is an MS extension.  See:
  # http://msdn.microsoft.com/workshop/author/dhtml/httponly_cookies.asp
  PerlSetVar WhatEverHttpOnly 1
 
+ # to enable the SameSite cookie property, set SameSite to "lax" or "strict".
+ # See: https://www.owasp.org/index.php/SameSite
+ PerlSetVar WhatEverSameSite strict
+
  # Usually documents are uncached - turn off here
  PerlSetVar WhatEverCache 1
 
@@ -358,8 +364,6 @@ again').
 
   where CODE is a valid code from Apache2::Const
 
-=encoding UTF-8
-
 =head1 EXAMPLE
 
 For an example of how to use C<Apache2_4::AuthCookie>, you may want to check
@@ -646,13 +650,17 @@ L<Apache2::AuthCookie::Base>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/mschout/apache-authcookie>
-and may be cloned from L<git://github.com/mschout/apache-authcookie.git>
+The development version is on github at L<https://https://github.com/mschout/apache-authcookie>
+and may be cloned from L<git://https://github.com/mschout/apache-authcookie.git>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to bug-apache-authcookie@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=Apache-AuthCookie
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/mschout/apache-authcookie/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
